#!/bin/bash

export PATH=/bin:/sbin:/usr/bin:/usr/sbin:/usr/bin/X11:/usr/local/bin:/usr/local/sbin:/usr/fallback

file=$1

if [ -z "$file" ]; then
	file=/dev/null
fi

DMESG1=/var/log/dmesg.log
DMESG2=/var/log/dmesg.log.1
DMESGTMP=/var/log/dmesg.tmp
OOPS_REBOOT_MINIMUM_UPTIME=600
OOPS_FILE=/tmp/kernel_oops
OOPS_LOG=/usr/conf/oops.log

function gather_dmesg {

	touch $DMESG1
	touch $DMESG2
	size=`ls -l $DMESG1 | awk  '{print $5}'`

#rotate it if it gets too big
	if [ $size -gt 50000 ]; then
		cp -f $DMESG1 $DMESG2
		echo "######  Rotating dmesg.log on " `date` > $DMESG1
	fi

	if [ "$file" = /tmp/fulltrace-info.txt ]; then
		echo -e "\n### dmesg fulltrace on " `date` >> $DMESG1
	fi

	dmesg -c |grep -v ^NWFPE > $DMESGTMP
	size=`ls -l $DMESGTMP | awk  '{print $5}'`

	if [ $size -gt 0 ]; then

		echo "###### new dmesg info on " `date` >> $DMESG1
		#check if we got a kernel oops, and if it is from isgw,  write it into oops log, if oops log set
		cat $DMESGTMP |grep "^Internal error: Oops:" &> /dev/null
		if [ $? = 0 ]; then
			cat $DMESGTMP |grep "^Process isgw" &> /dev/null
			if [ $? = 0 ]; then
				touch "$OOPS_FILE"
				if [ -n "$OOPS_LOG" ]; then
					echo OOPS OCCURRED: `date` > $OOPS_LOG
					cat $DMESGTMP >> "$OOPS_LOG"
				fi
			fi
		fi
		cat $DMESGTMP >> $DMESG1
	fi

	#reboot if minimum uptime has been reached, check if rebooting hasn't been disabled in isgw.conf experimental options
	if [ -f "$OOPS_FILE" ]; then
		UPTIME=`cat /proc/uptime|sed 's/\..*//'`
		OOPS_REBOOT_ALLOWED=1
		if [ $UPTIME -gt $OOPS_REBOOT_MINIMUM_UPTIME ]; then
			if [ -f /usr/conf/isgw.conf ]; then
				cat /usr/conf/isgw.conf|grep "experimental_options.*oops_reboot_disabled=1"
				if [ $? = 0 ]; then
					OOPS_REBOOT_ALLOWED=0
				fi
			fi

			if [ $OOPS_REBOOT_ALLOWED = 1 ]; then
				reboot
			fi
		fi
	fi

}

log_info()
{
	echo -e "\n#######" "$1:" >> $file
	eval $1 >> $file
}

gather_dmesg

log_info "echo q | top"
log_info "date"
log_info "uptime"
log_info "free"
log_info "ps aux"
log_info "df"
# log_info "dmesg"
log_info "cat /sys/class/beronet/li*/module"
log_info "cat /proc/meminfo"
log_info "cat /proc/cmdline"
log_info "cat /sys/class/beronet/fpga/version"
log_info "cat /proc/interrupts"
log_info "cat /proc/l1_stats"
log_info "cat /proc/l2_stats"
log_info "lsmod"
log_info "ifconfig"
log_info "ifconfig -a"
log_info "iptables -L -n"
log_info "iptables -L -t nat -n"
log_info "netstat -na"

